aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDaniel d'Andrada <daniel.dandrada@nokia.com>2010-09-17 14:28:33 +0300
committerDaniel d'Andrada <daniel.dandrada@nokia.com>2010-09-17 14:31:25 +0300
commitd9446738c8786dbc79fb45a3c4ffe45887edd7f0 (patch)
treea752cacfb521148a5785f04642e09bdf11068fad
parent4d7f65b2015297ed0646b7fdcf308caf2a734d2b (diff)
Changes: MDialog - Expand documentation on some deprecated methods
Fixes: NB#192722, setters/getters for MDialogStyle's has-title-bar does not work and/or exists Fixes: NB#192723, setters/getters for MDialogStyle's has-close-button does not work and/or exists RevBy: TrustMe
-rw-r--r--src/corelib/widgets/mdialog.h21
-rw-r--r--src/corelib/widgets/mdialogmodel.h8
2 files changed, 21 insertions, 8 deletions
diff --git a/src/corelib/widgets/mdialogmodel.h b/src/corelib/widgets/mdialogmodel.h
index 35affc35..95821293 100644
--- a/src/corelib/widgets/mdialogmodel.h
+++ b/src/corelib/widgets/mdialogmodel.h
@@ -40,14 +40,18 @@ private:
/*!
\property MDialogModel::closeButtonVisible
- \deprecated Use MDialogStyle::hasCloseButton instead.
+ \deprecated Use MDialogStyle::hasCloseButton instead. OBS: Style properties
+ are set in CSS files and consumed by the assigned view.
+
*/
M_MODEL_PROPERTY(bool, closeButtonVisible, CloseButtonVisible, true, true)
M_MODEL_PROPERTY(bool, buttonBoxVisible, ButtonBoxVisible, true, true)
/*!
\property MDialogModel::titleBarVisible
- \deprecated Use MDialogStyle::hasTitleBar instead.
+ \deprecated Use MDialogStyle::hasTitleBar instead. OBS: Style properties
+ are set in CSS files and consumed by the assigned view.
+
*/
M_MODEL_PROPERTY(bool, titleBarVisible, TitleBarVisible, true, true)
M_MODEL_PROPERTY(QString, title, Title, true, QString())
diff --git a/src/corelib/widgets/mdialog.h b/src/corelib/widgets/mdialog.h
index ce7e7241..336410ac 100644
--- a/src/corelib/widgets/mdialog.h
+++ b/src/corelib/widgets/mdialog.h
@@ -175,7 +175,8 @@ class M_EXPORT MDialog : public MSceneWindow
/*!
\property MDialog::closeButtonVisible
\brief Whether the close button should be visible.
- \deprecated Use MDialogStyle::hasCloseButton instead.
+ \deprecated Use MDialogStyle::hasCloseButton instead. OBS: Style properties
+ are set in CSS files and consumed by the assigned view.
The dialog's optional close button is provided as a convenient way of
rejecting the dialog and discarding all changes. It's visible by default.
@@ -188,7 +189,8 @@ class M_EXPORT MDialog : public MSceneWindow
/*!
\property MDialog::titleBarVisible
\brief Whether the title bar should be visible.
- \deprecated Use MDialogStyle::hasTitleBar instead.
+ \deprecated Use MDialogStyle::hasTitleBar instead. OBS: Style properties are
+ set in CSS files and consumed by the assigned view.
The title bar sits on top of the dialog and contains a title text, an
optional close button and an optional progress indicator.
@@ -290,14 +292,18 @@ public:
/*!
* \brief Returns true if the dialog's close button is visible, false otherwise.
* \deprecated Use MDialogStyle::hasCloseButton instead.
* \sa setCloseButtonVisible()
*/
bool isCloseButtonVisible() const;
/*!
* \brief Sets the visibility of the dialog's close button.
* \deprecated Use MDialogStyle::hasCloseButton instead.
*
* \sa isCloseButtonVisible(), setTitleBarVisible()
*/
@@ -326,14 +332,17 @@ public:
/*!
* \brief Returns true if the dialog's title bar is visible and false otherwise.
* \deprecated Use MDialogStyle::hasTitleBar instead.
* \sa setTitleBarVisible()
*/
bool isTitleBarVisible() const;
/*!
* \brief Sets the visibility of the dialog's title bar.
* \deprecated Use MDialogStyle::hasTitleBar instead.
*
* \sa isTitleBarVisible(), setCloseButtonVisible(), setTitle()
*/
@@ -290,14 +292,18 @@ public:
/*!
* \brief Returns true if the dialog's close button is visible, false otherwise.
- * \deprecated Use MDialogStyle::hasCloseButton instead.
+ * \deprecated Use MDialogStyle::hasCloseButton instead. OBS: Style properties
+ * are set in CSS files and consumed by the assigned view.
+ *
* \sa setCloseButtonVisible()
*/
@@ -290,14 +292,18 @@ public:
/*!
* \brief Sets the visibility of the dialog's close button.
- * \deprecated Use MDialogStyle::hasCloseButton instead.
+ * \deprecated Use MDialogStyle::hasCloseButton instead. OBS: Style properties
+ * are set in CSS files and consumed by the assigned view.
+ *
*
* \sa isCloseButtonVisible(), setTitleBarVisible()
@@ -326,14 +332,17 @@ public:
/*!
* \brief Returns true if the dialog's title bar is visible and false otherwise.
- * \deprecated Use MDialogStyle::hasTitleBar instead.
+ * \deprecated Use MDialogStyle::hasTitleBar instead. OBS: Style properties
+ * are set in CSS files and consumed by the assigned view.
+ *
* \sa setTitleBarVisible()
*/
@@ -326,14 +332,17 @@ public:
/*!
* \brief Sets the visibility of the dialog's title bar.
- * \deprecated Use MDialogStyle::hasTitleBar instead.
+ * \deprecated Use MDialogStyle::hasTitleBar instead. OBS: Style properties
+ * are set in CSS files and consumed by the assigned view.
*
* \sa isTitleBarVisible(), setCloseButtonVisible(), setTitle()